#ifndef __PILOTSKINCONFIG_H
#define __PILOTSKINCONFIG_H


struct sPilotskinConfig {
  int closeonswitch;
  int hidemenu;
};

extern sPilotskinConfig config;

// #define DEBUG

#endif //__PILOTSKINCONFIG_H

